leap.common
===========

.. image:: https://pypip.in/v/leap.common/badge.png
        :target: https://crate.io/packages/leap.common

A collection of shared utils used by the several python LEAP subprojects.

* leap.common.cert
* leap.common.checks
* leap.common.config
* leap.common.events
* leap.common.files
* leap.common.testing

Library dependencies
--------------------
* ``protobuf-compiler``
* ``libssl-dev``

Python dependencies
-------------------
* See ``pkg/requirements.pip``
